# Install this package as a guile alternative.

GUILE_VERSION=3.0
GUILE_PRIORITY=3001

/usr/sbin/alternatives --install /usr/bin/guile guile /usr/bin/guile-$GUILE_VERSION $GUILE_PRIORITY
/usr/sbin/alternatives --install /usr/bin/guild guild /usr/bin/guild-$GUILE_VERSION $GUILE_PRIORITY
/usr/sbin/alternatives --install /usr/bin/guile-config guile-config /usr/bin/guile-config-$GUILE_VERSION $GUILE_PRIORITY
/usr/sbin/alternatives --install /usr/bin/guile-snarf guile-snarf /usr/bin/guile-snarf-$GUILE_VERSION $GUILE_PRIORITY
/usr/sbin/alternatives --install /usr/bin/guile-tools guile-tools /usr/bin/guile-tools-$GUILE_VERSION $GUILE_PRIORITY
