# Remove this package as a guile alternative.

/usr/sbin/alternatives --remove guile /usr/bin/guile-3.0
/usr/sbin/alternatives --remove guild /usr/bin/guild-3.0
/usr/sbin/alternatives --remove guile-config /usr/bin/guile-config-3.0
/usr/sbin/alternatives --remove guile-snarf /usr/bin/guile-snarf-3.0
/usr/sbin/alternatives --remove guile-tools /usr/bin/guile-tools-3.0
